@@ -8,6 +8,7 @@ import webbrowser
 import time
 import ast
 import Utils
+import urllib.parse
 
 apname = Utils.instance_name if Utils.instance_name else "Archipelago"
 
@@ -433,11 +434,11 @@ class APosuContext(CommonContext):
     items_handling = 0b111  # full remote
     want_slot_data = True
 
-    def __init__(self, server_address, slot_name, password, ready_callback=None, error_callback=None):
+    def __init__(self, server_address, password, ready_callback=None, error_callback=None):
         super(APosuContext, self).__init__(server_address, password)
         self.ready_callback = ready_callback
         self.error_callback = error_callback
-        self.username = slot_name
+        self.username = urllib.parse.urlparse(server_address).username
         self.send_index: int = 0
         self.pairs: dict = {}
         self.last_scores: list = []
@@ -881,7 +882,7 @@ async def game_watcher(ctx: APosuContext):
         await asyncio.sleep(0.1)
 
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """
     Launch the client
     """
@@ -889,7 +890,7 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
     logging.getLogger("OsuClient")
 
     async def main():
-        ctx = APosuContext(server_address, slot_name, password, ready_callback, error_callback)
+        ctx = APosuContext(server_address, password, ready_callback, error_callback)
         if ctx._can_takeover_existing_gui():
             await ctx._takeover_existing_gui() 
         else:
@@ -927,9 +928,9 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
             error_callback()
 
 
-def main(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback)
+    launch(server_address, password, ready_callback, error_callback)
 
 
 if __name__ == '__main__':
